EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Packages_GetPackages',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Packages_Combined',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a list of combined packages filtering by the specified criteria.'
GO

IF OBJECT_ID('[Packages_GetPackages]') IS NOT NULL DROP PROCEDURE [Packages_GetPackages]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Packages_GetPackages]
(
	@Packages_Count INT = NULL,
    @Feed_Id INT = NULL,
    @PublishedBefore_Date DATETIME = NULL,
	@FeedIds_Csv VARCHAR(MAX) = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	IF @FeedIds_Csv IS NULL BEGIN

	    IF @Packages_Count IS NOT NULL
			SET ROWCOUNT @Packages_Count

		SELECT * 
	      FROM [Packages_Combined]
	     WHERE (@Feed_Id IS NULL OR [Feed_Id] = @Feed_Id)
	       AND (@PublishedBefore_Date IS NULL OR [Published_Date] < @PublishedBefore_Date)
	     ORDER BY [Published_Date] DESC

	END ELSE BEGIN

		DECLARE @FeedIds TABLE([Feed_Id] INT NOT NULL)
		INSERT INTO @FeedIds
		SELECT CAST([Value_Text] AS INT)
		  FROM dbo.CsvToTable(@FeedIds_Csv, ',')

		IF @Packages_Count IS NOT NULL
			SET ROWCOUNT @Packages_Count

		SELECT * 
	      FROM [Packages_Combined]
	     WHERE ([Feed_Id] IN (SELECT [Feed_Id] FROM @FeedIds))
	       AND (@PublishedBefore_Date IS NULL OR [Published_Date] < @PublishedBefore_Date)
	     ORDER BY [Published_Date] DESC

	END

END
GO

GRANT EXECUTE ON [Packages_GetPackages] TO [ProGetUser_Role]
GO